@@ -13,7 +13,7 @@ Modified from http://code.activestate.com/recipes/491261/
 from __future__ import with_statement
 
 __author__ = "dbr/Ben"
-__version__ = "1.2"
+__version__ = "1.2.1"
 
 import os
 import time
@@ -65,7 +65,7 @@ class FileLock(object):
             try:
                 self.fd = os.open(self.lockfile, os.O_CREAT|os.O_EXCL|os.O_RDWR)
                 break;
-            except OSError as e:
+            except OSError, e:
                 if e.errno != errno.EEXIST:
                     raise e
                 if (time.time() - start_time) >= self.timeout:
