@@ -16,7 +16,7 @@ Example usage:
 u'Cabin Fever'
 """
 __author__ = "dbr/Ben"
-__version__ = "1.1"
+__version__ = "1.2.1"
 
 import os
 import sys
@@ -150,7 +150,7 @@ class Season(dict):
         instances.
 
         >>> t = Tvdb()
-        >>> t['scrubs'][1].search('first')
+        >>> t['scrubs'][1].search('first day')
         [<Episode 01x01 - My First Day>]
         >>>
 
@@ -421,7 +421,7 @@ class Tvdb:
                 if recache:
                     self.log.debug("Attempting to recache %s" % url)
                     resp.recache()
-        except IOError, errormsg:
+        except urllib2.URLError, errormsg:
             raise tvdb_error("Could not connect to server: %s" % (errormsg))
         #end try
 
